from poocr.api import ocr
from poocr.api import ocr2excel
from poocr.lib.Const import SPLIT_LINE

print(SPLIT_LINE)
print('【poocr库】，功能持续更新中')
print('使用有问题 or 提交你的功能需求 or 参与项目开发')
print('1、全部功能【视频 & 文字】教程：https://mp.weixin.qq.com/s/WxICBZZSgkm-OrvXB82hbg')
print('2、请+【项目交流群】：http://t.cn/A65MiFvH')
print('3、本开源项目的【代码仓库】：https://github.com/CoderWanFeng/poocr')
print(SPLIT_LINE)